psychopy_ext.exp.Task.__init__ — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.Task.__init__

`Task.` `__init__`(parent, name='', version='0.1', method='random', data_fname=None, blockcol=None)

  An extension of TrialHandler with many useful functions.

  Args: | parent (`Experiment`) The Experiment to which this Tast belongs.
  Kwargs: | name (str, default: ‘’) Name of the task. Currently not used anywhere. version (str, default: ‘0.1’) Version of your experiment. method ({‘sequential’, ‘random’}, default: ‘random’) Order of trials: sequential: trials and blocks presented sequentially random: trials presented randomly, blocks sequentially fullRandom: converted to ‘random’ Note that there is no explicit possibility to randomize the order of blocks. This is intentional because you in fact define block order in the blockcol. data_fname (str, default=None) The name of the main data file for storing output. If None, reuses `Datafile` instance from its parent; otherwise, a new one is created (stored in `self.datafile`). blockcol (str, default: None) Column name in self.exp_plan that defines which trial should be presented during which block.